@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: ChenXiaolei
-@Date: 2020-05-11 21:46:17
-@LastEditTime: 2020-05-25 16:29:57
-@LastEditors: ChenXiaolei
-@Description: 
+:Author: ChenXiaolei
+:Date: 2020-05-11 21:46:17
+:LastEditTime: 2020-12-25 09:48:31
+:LastEditors: ChenXiaolei
+:Description: 编码类型组件
 """
 
 from urllib import parse
