@@ -1,11 +1,11 @@
 
 # -*- coding: utf-8 -*-
 """
-@Author: ChenXiaolei
-@Date: 2020-11-04 10:37:38
-@LastEditTime: 2020-11-04 17:26:14
-@LastEditors: ChenXiaolei
-@Description: csv helper
+:Author: ChenXiaolei
+:Date: 2020-11-04 10:37:38
+:LastEditTime: 2020-12-25 10:50:02
+:LastEditors: ChenXiaolei
+:Description: csv helper
 """
 import csv
 import os
@@ -19,10 +19,10 @@ class CSVHelper:
         
     def input(self,file_name):
         """
-        @description: 导入csv文件
-        @param file_name: 文件名（包含地址）
-        @return 二维数组
-        @last_editors: ChenXiaolei
+        :Description: 导入csv文件
+        :param file_name: 文件名（包含地址）
+        :return 二维数组
+        :last_editors: ChenXiaolei
         """
         if self.__file_name=="":
             self.open(file_name)
@@ -30,11 +30,11 @@ class CSVHelper:
     
     def export(self, dict_list, file_name=""):
         """
-        @description: 数据导出到csv
-        @param data: 字典数组 
-        @param file_name: 文件名（包含地址）,默认在当前文件夹下创建一个"新建export.csv" 
-        @return: 导出成功True 失败False
-        @last_editors: ChenXiaolei
+        :Description: 数据导出到csv
+        :param data: 字典数组 
+        :param file_name: 文件名（包含地址）,默认在当前文件夹下创建一个"新建export.csv" 
+        :return: 导出成功True 失败False
+        :last_editors: ChenXiaolei
         """
         if not file_name:
             file_name = self.__get_file_name_by_csv()
@@ -56,9 +56,9 @@ class CSVHelper:
         
     def __get_file_name_by_csv(self):
         """
-        @description: 获取文件名
-        @return 获取文件名,默认(文件目录/export.csv)
-        @last_editors: ChenXiaolei
+        :Description: 获取文件名
+        :return 获取文件名,默认(文件目录/export.csv)
+        :last_editors: ChenXiaolei
         """
         if self.__file_name=='':
             return os.path.abspath('.') + r'/export.csv'
@@ -66,9 +66,9 @@ class CSVHelper:
         
     def __insert_blank_row(self):
         """
-        @description: 插入空行
-        @return 无
-        @last_editors: ChenXiaolei
+        :Description: 插入空行
+        :return 无
+        :last_editors: ChenXiaolei
         """
         if self.__max_row != 0 and self.__max_col != 0:
             row_data = ['']*self.__max_col
@@ -79,9 +79,9 @@ class CSVHelper:
 
     def __insert_blank_column(self):
         """
-        @description: 插入空列
-        @return 无
-        @last_editors: ChenXiaolei
+        :Description: 插入空列
+        :return 无
+        :last_editors: ChenXiaolei
         """
         if self.__max_row != 0 and self.__max_col != 0:
             col_data = [''] * self.__max_row
@@ -93,9 +93,9 @@ class CSVHelper:
 
     def __create_blank_cell(self):
         """
-        @description: 创建一个单元格
-        @return 无
-        @last_editors: ChenXiaolei
+        :Description: 创建一个单元格
+        :return 无
+        :last_editors: ChenXiaolei
         """
         if self.__max_row == 0 and self.__max_col == 0:
             col_data = ['']
@@ -105,10 +105,10 @@ class CSVHelper:
 
     def create(self, file_name=''):
         """
-        @description: 创建csv文件
-        @param file_name: 文件名(带路径)
-        @return 创建成功True 创建失败False
-        @last_editors: ChenXiaolei
+        :Description: 创建csv文件
+        :param file_name: 文件名(带路径)
+        :return: 创建成功True 创建失败False
+        :last_editors: ChenXiaolei
         """
         if file_name == '':
             self.__file_name = '新建文件.csv'
@@ -130,10 +130,10 @@ class CSVHelper:
 
     def open(self, file_name):
         """
-        @description: 打开csv文件
-        @param file_name: 文件名(带路径)
-        @return 打开文件成功True 打开文件失败False
-        @last_editors: ChenXiaolei
+        :Description: 打开csv文件
+        :param file_name: 文件名(带路径)
+        :return 打开文件成功True 打开文件失败False
+        :last_editors: ChenXiaolei
         """
         try:
             with open(file_name, 'r', newline='') as file:
@@ -155,10 +155,10 @@ class CSVHelper:
 
     def get_row(self, row_index):
         """
-        @description: 提取CSV中的行,返回列表
-        @param row_index: 行索引下标(从0开始)
-        @return 行数据(数组)
-        @last_editors: ChenXiaolei
+        :Description: 提取CSV中的行,返回列表
+        :param row_index: 行索引下标(从0开始)
+        :return 行数据(数组)
+        :last_editors: ChenXiaolei
         """
         if self.__file_name == '':
             print('请先打开csv文件')
@@ -174,10 +174,10 @@ class CSVHelper:
 
     def get_column(self, col_index):
         """
-        @description: 提取CSV中的列,返回列表
-        @param col_index: 列索引下标(从0开始)
-        @return 列数据(数组)
-        @last_editors: ChenXiaolei
+        :Description: 提取CSV中的列,返回列表
+        :param col_index: 列索引下标(从0开始)
+        :return 列数据(数组)
+        :last_editors: ChenXiaolei
         """
         if self.__file_name == '':
             print('请先打开csv文件')
@@ -193,11 +193,11 @@ class CSVHelper:
 
     def get_cell(self, row_index, col_index):
         """
-        @description: 提取CSV单元格
-        @param row_index: 行索引下标
-        @param col_index: 列索引下标
-        @return 单元格数据
-        @last_editors: ChenXiaolei
+        :Description: 提取CSV单元格
+        :param row_index: 行索引下标
+        :param col_index: 列索引下标
+        :return 单元格数据
+        :last_editors: ChenXiaolei
         """
         if self.__file_name == '':
             print('请先打开csv文件')
@@ -216,11 +216,11 @@ class CSVHelper:
 
     def insert_row(self, row_index, row_data=[]):
         """
-        @description: 插入行数据
-        @param row_index: 行索引下标(从0开始)
-        @param row_data: 行数据(数组)
-        @return 成功True 失败False
-        @last_editors: ChenXiaolei
+        :Description: 插入行数据
+        :param row_index: 行索引下标(从0开始)
+        :param row_data: 行数据(数组)
+        :return 成功True 失败False
+        :last_editors: ChenXiaolei
         """
         if self.__max_col == 0 and self.__max_row == 0:
             return self.set_row(row_index, row_data)
@@ -250,11 +250,11 @@ class CSVHelper:
 
     def insert_column(self, col_index, col_data=[]):
         """
-        @description: 插入列数据
-        @param col_index: 列索引下标(从0开始)
-        @param col_data: 列数据(数组)
-        @return 成功True 失败False
-        @last_editors: ChenXiaolei
+        :Description: 插入列数据
+        :param col_index: 列索引下标(从0开始)
+        :param col_data: 列数据(数组)
+        :return 成功True 失败False
+        :last_editors: ChenXiaolei
         """
         if self.__max_col == 0 and self.__max_row == 0:
             return self.set_column(col_index, col_data)
@@ -287,10 +287,10 @@ class CSVHelper:
 
     def delete_row(self, row_index):
         """
-        @description: 删除行
-        @param row_index: 行索引下标(从0开始)
-        @return 成功True 失败False
-        @last_editors: ChenXiaolei
+        :Description: 删除行
+        :param row_index: 行索引下标(从0开始)
+        :return 成功True 失败False
+        :last_editors: ChenXiaolei
         """
         if self.__file_name == '':
             print('请先打开csv文件')
@@ -308,10 +308,10 @@ class CSVHelper:
 
     def delete_column(self, col_index):
         """
-        @description: 删除列
-        @param col_index: 列索引下标(从0开始)
-        @return 成功True 失败False
-        @last_editors: ChenXiaolei
+        :Description: 删除列
+        :param col_index: 列索引下标(从0开始)
+        :return 成功True 失败False
+        :last_editors: ChenXiaolei
         """
         if self.__file_name == '':
             print('请先打开csv文件')
@@ -330,11 +330,11 @@ class CSVHelper:
 
     def delete_row_by_key(self, col_index, key):
         """
-        @description: 以col_index列为查找源，删除=key的行
-        @param col_index: 列索引下标(从0开始)
-        @param key: 满足条件的key值
-        @return 成功True 失败False
-        @last_editors: ChenXiaolei
+        :Description: 以col_index列为查找源，删除=key的行
+        :param col_index: 列索引下标(从0开始)
+        :param key: 满足条件的key值
+        :return 成功True 失败False
+        :last_editors: ChenXiaolei
         """
         if self.__file_name == '':
             print('请先打开csv文件')
@@ -354,11 +354,11 @@ class CSVHelper:
 
     def delete_column_by_key(self, row_index, key):
         """
-        @description: 以row_index列为查找源，删除=key的列
-        @param row_index: 行索引下标(从0开始)
-        @param key: 满足条件的key值
-        @return 成功True 失败False
-        @last_editors: ChenXiaolei
+        :Description: 以row_index列为查找源，删除=key的列
+        :param row_index: 行索引下标(从0开始)
+        :param key: 满足条件的key值
+        :return 成功True 失败False
+        :last_editors: ChenXiaolei
         """
         if self.__file_name == '':
             print('请先打开csv文件')
@@ -376,11 +376,11 @@ class CSVHelper:
 
     def set_row(self, row_index, row_data):
         """
-        @description: 写行数据，覆盖原来的数据
-        @param row_index: 行索引下标(从0开始)
-        @param row_data: 行数据(数组)
-        @return 写入成功True
-        @last_editors: ChenXiaolei
+        :Description: 写行数据，覆盖原来的数据
+        :param row_index: 行索引下标(从0开始)
+        :param row_data: 行数据(数组)
+        :return 写入成功True
+        :last_editors: ChenXiaolei
         """
         temp_data = [temp for temp in row_data]
         if self.__file_name == '':
@@ -411,11 +411,11 @@ class CSVHelper:
 
     def set_column(self, col_index, col_data):
         """
-        @description: 写列数据，覆盖原来的数据
-        @param col_index: 列索引下标(从0开始)
-        @param col_data: 列数据(数组)
-        @return 成功True 失败False
-        @last_editors: ChenXiaolei
+        :Description: 写列数据，覆盖原来的数据
+        :param col_index: 列索引下标(从0开始)
+        :param col_data: 列数据(数组)
+        :return 成功True 失败False
+        :last_editors: ChenXiaolei
         """
         temp_data = [temp for temp in col_data]
         if self.__file_name == '':
@@ -449,12 +449,12 @@ class CSVHelper:
 
     def set_cell(self, row_index, col_index, data):
         """
-        @description: 写列数据，覆盖原来的数据
-        @param row_index: 行索引下标(从0开始)
-        @param col_index: 列索引下标(从0开始)
-        @param data: 单元格数据
-        @return 成功True 失败False
-        @last_editors: ChenXiaolei
+        :Description: 写列数据，覆盖原来的数据
+        :param row_index: 行索引下标(从0开始)
+        :param col_index: 列索引下标(从0开始)
+        :param data: 单元格数据
+        :return 成功True 失败False
+        :last_editors: ChenXiaolei
         """
         if self.__file_name == '':
             print('请先打开csv文件')
@@ -473,11 +473,11 @@ class CSVHelper:
 
     def get_column_index(self, row_index, key):
         """
-        @description: 以row_index行为查找源，返回=key的列索引号
-        @param row_index: 行索引下标(从0开始)
-        @param key: 需满足条件的key
-        @return 列索引
-        @last_editors: ChenXiaolei
+        :Description: 以row_index行为查找源，返回=key的列索引号
+        :param row_index: 行索引下标(从0开始)
+        :param key: 需满足条件的key
+        :return 列索引
+        :last_editors: ChenXiaolei
         """
         row_data = self.get_row(row_index)
         if key not in row_data:
@@ -487,11 +487,11 @@ class CSVHelper:
 
     def get_row_index(self, col_index, key):
         """
-        @description: 以col_index列为查找源，返回=key的行索引号
-        @param col_index: 列索引下标(从0开始)
-        @param key: 需满足条件的key
-        @return 行索引
-        @last_editors: ChenXiaolei
+        :Description: 以col_index列为查找源，返回=key的行索引号
+        :param col_index: 列索引下标(从0开始)
+        :param key: 需满足条件的key
+        :return 行索引
+        :last_editors: ChenXiaolei
         """
         col_data = self.get_column(col_index)
         if key not in col_data:
@@ -501,26 +501,26 @@ class CSVHelper:
 
     def get_max_row(self):
         """
-        @description: 获取最大行数
-        @return 最大行数
-        @last_editors: ChenXiaolei
+        :Description: 获取最大行数
+        :return 最大行数
+        :last_editors: ChenXiaolei
         """
         return self.__max_row
 
     def get_max_column(self):
         """
-        @description: 获取最大列数
-        @return 最大列数
-        @last_editors: ChenXiaolei
+        :Description: 获取最大列数
+        :return 最大列数
+        :last_editors: ChenXiaolei
         """
         return self.__max_col
 
     def save(self, file_name=''):
         """
-        @description: 保存csv文件
-        @param file_name: 文件名(带路径)
-        @return 成功True 失败False
-        @last_editors: ChenXiaolei
+        :Description: 保存csv文件
+        :param file_name: 文件名(带路径)
+        :return 成功True 失败False
+        :last_editors: ChenXiaolei
         """
         if file_name != '':
             self.__file_name = file_name
