@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-04-16 21:32:43
-:LastEditTime: 2021-03-04 18:23:53
+:LastEditTime: 2021-03-16 17:17:09
 :LastEditors: ChenXiaolei
 :Description: 日志帮助类
 """
@@ -249,8 +249,6 @@ class LoggerStorageHandler(logging.Handler):
         :return: 无
         :last_editors: ChenXiaolei
         """
-        request_code = self.request_code if hasattr(self,
-                                                    "request_code") else ""
         project_name = self.project_name
         level = record.levelname
         host_ip = self.host_ip
@@ -267,7 +265,7 @@ class LoggerStorageHandler(logging.Handler):
                         extra_sql_value += f",'{record.extra[key]}'"
 
                 self.mysql_db.fetch_and_commit(
-                    f"INSERT INTO {self.table_name}(request_code,project_name,level,host_ip,record_time,record_timestamp,log_msg{extra_sql_field}) VALUE('{request_code}','{project_name}','{level}','{host_ip}','{time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(record_time))}',{record_time},'{pymysql.converters.escape_string(log_msg)}'{extra_sql_value});"
+                    f"INSERT INTO {self.table_name}(project_name,level,host_ip,record_time,record_timestamp,log_msg{extra_sql_field}) VALUE('{project_name}','{level}','{host_ip}','{time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(record_time))}',{record_time},'{pymysql.converters.escape_string(log_msg)}'{extra_sql_value});"
                 )
             except:
                 print("日志入库异常:" + traceback.format_exc())
@@ -302,7 +300,7 @@ class LoggerStorageHandler(logging.Handler):
                         extra_sql_value += f",'{record.extra[key]}'"
 
                 self.clickhouse_client.execute(
-                    f"INSERT INTO {self.table_name}(request_code,project_name,level,host_ip,record_time,log_msg{extra_sql_field}) VALUES('{request_code}','{project_name}','{level}','{host_ip}',{record_time},'{pymysql.converters.escape_string(log_msg)}'{extra_sql_value});"
+                    f"INSERT INTO {self.table_name}(project_name,level,host_ip,record_time,log_msg{extra_sql_field}) VALUES('{project_name}','{level}','{host_ip}',{record_time},'{pymysql.converters.escape_string(log_msg)}'{extra_sql_value});"
                 )
             except:
                 print("日志写入clickhouse异常:" + traceback.format_exc())
