@@ -45,7 +45,8 @@ class MySQLHelper(object):
             charset=dbconfig['charset'])
 
         try:
-            self._log_sql = log.Logger.get_logger_by_name("log_sql")
+            if not hasattr(self,"context") or self.context:
+                self._log_sql = log.Logger.get_logger_by_name("log_sql")
         except:
             pass
 
@@ -57,16 +58,18 @@ class MySQLHelper(object):
         :last_editors: ChenXiaolei
         """
         try:
-            if hasattr(self, "_log_sql") and self._log_sql:
-                if type(log) == int:
-                    log = str(log)
-                elif type(log) != str:
-                    log = json.JsonHelper.json_dumps(log)
+            if type(log) == int:
+                log = str(log)
+            elif type(log) != str:
+                log = json.JsonHelper.json_dumps(log)
 
-                self.sql_log_dict["result"] = log
-
-                self._log_sql.info(
-                    json.JsonHelper.json_dumps(self.sql_log_dict))
+            self.sql_log_dict["result"] = log
+            log_msg = json.JsonHelper.json_dumps(self.sql_log_dict)
+            # 如果有handler上下文,则使用链路日志记录
+            if hasattr(self, "context") and self.context:
+                self.context.logging_link_sql(log_msg)
+            else:
+                self._log_sql.info(log_msg)
         except:
             print(traceback.print_exc())
             pass
