@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-06 23:17:54
-:LastEditTime: 2021-03-04 18:23:30
+:LastEditTime: 2021-03-16 17:17:42
 :LastEditors: ChenXiaolei
 :Description: Handler基础类
 """
@@ -34,12 +34,12 @@ class BaseHandler(tornado.web.RequestHandler):
     """
     executor = ThreadPoolExecutor(THREAD_POOL_COUNT)
 
-    def __init__(self, *argc, **argkw):
+    def __init__(self, *args, **argkw):
         """
         :Description: 初始化
         :last_editors: ChenXiaolei
         """
-        super(BaseHandler, self).__init__(*argc, **argkw)
+        super(BaseHandler, self).__init__(*args, **argkw)
         self.logger_error = Logger.get_logger_by_name("log_error")
         self.logger_info = Logger.get_logger_by_name("log_info")
         self.logger_sql = Logger.get_logger_by_name("log_sql")
@@ -70,7 +70,7 @@ class BaseHandler(tornado.web.RequestHandler):
         await asyncio.get_event_loop().run_in_executor(self.executor,
                                                        self.options_async)
 
-    def prepare(self, *argc, **argkw):
+    def prepare(self, *args, **argkw):
         """
         :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
         :last_editors: ChenXiaolei
@@ -87,24 +87,7 @@ class BaseHandler(tornado.web.RequestHandler):
 
     def _build_http_log(self, http_log_extra_dict=None):
         self.request_code = UUIDHelper.get_uuid()
-
-        if hasattr(self, "logger_info"):
-            for index in range(len(self.logger_info.handlers)):
-                self.logger_info.handlers[
-                    index].request_code = self.request_code
-        if hasattr(self, "logger_error"):
-            for index in range(len(self.logger_error.handlers)):
-                self.logger_error.handlers[
-                    index].request_code = self.request_code
-        if hasattr(self, "logger_sql"):
-            for index in range(len(self.logger_sql.handlers)):
-                self.logger_sql.handlers[
-                    index].request_code = self.request_code
-        if hasattr(self, "logger_http"):
-            for index in range(len(self.logger_http.handlers)):
-                self.logger_http.handlers[
-                    index].request_code = self.request_code
-
+        print("---------request request_code:" + self.request_code)
         # 请求信息
         try:
             if "Content-Type" in self.request.headers and self.request.headers[
@@ -128,10 +111,11 @@ class BaseHandler(tornado.web.RequestHandler):
 
             if not http_log_extra_dict:
                 http_log_extra_dict = {}
-            if "handler" not in http_log_extra_dict:
-                http_log_extra_dict["handler"] = self.__class__.__name__
-            if "action_mode" not in http_log_extra_dict:
-                http_log_extra_dict["action_mode"] = "request"
+            # if "handler" not in http_log_extra_dict:
+            http_log_extra_dict["handler"] = self.__class__.__name__
+            # if "action_mode" not in http_log_extra_dict:
+            http_log_extra_dict["action_mode"] = "request"
+            http_log_extra_dict["request_code"] = self.request_code
             self.logger_http.info(http_request_msg,
                                   extra={"extra": http_log_extra_dict})
 
@@ -249,7 +233,11 @@ class BaseHandler(tornado.web.RequestHandler):
         :Description: 重写全局异常事件捕捉
         :last_editors: ChenXiaolei
         """
-        self.logger_error.error(traceback.format_exc())
+        self.logger_error.error(
+            traceback.format_exc(),
+            extra={"extra": {
+                "request_code": self.request_code
+            }})
 
     def get_param(self, param_name, default="", strip=True):
         """
@@ -306,6 +294,7 @@ class BaseHandler(tornado.web.RequestHandler):
         self.logger_http.info(content_log_info,
                               extra={
                                   "extra": {
+                                      "request_code": self.request_code,
                                       "handler": self.__class__.__name__,
                                       "action_mode": "output"
                                   }
@@ -367,6 +356,7 @@ class BaseHandler(tornado.web.RequestHandler):
         self.logger_http.info(content_log_info,
                               extra={
                                   "extra": {
+                                      "request_code": self.request_code,
                                       "handler": self.__class__.__name__,
                                       "action_mode": "output"
                                   }
@@ -418,6 +408,86 @@ class BaseHandler(tornado.web.RequestHandler):
 
         self.redirect(url, permanent, status)
 
+    def logging_link(self, msg, level, extra_dict=None):
+        """
+        :description: 记录请求链路日志
+        :param msg: 日志内容
+        :param level: 日志级别
+        :param extra_dict: 扩展参数字典
+        :return 无
+        :last_editors: ChenXiaolei
+        """
+        if not extra_dict or type(extra_dict) != dict:
+            extra_dict = {}
+
+        extra_dict["request_code"] = self.request_code
+
+        extra = {"extra": extra_dict}
+
+        try:
+            if level.lower() == "info":
+                self.logger_info.info(msg, extra=extra)
+            elif level.lower() == "error":
+                self.logger_error.error(msg, extra=extra)
+            elif level.lower() == "sql":
+                self.logger_sql.info(msg, extra=extra)
+            elif level.lower() == "http":
+                self.logger_http.info(msg, extra=extra)
+            else:
+                self.logger_error.error(
+                    f"未知level日志:level:{level} 日志内容:{msg} extra:{JsonHelper.json_dumps(extra_dict) if extra_dict else ''}"
+                )
+        except:
+            pass
+
+    def logging_link_http(self, msg, extra_dict=None):
+        """
+        :description: 记录请求链路日志(http)
+        :param msg: 日志内容
+        :return 无
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.logging_link(msg, "http", extra_dict)
+        except:
+            pass
+
+    def logging_link_info(self, msg, extra_dict=None):
+        """
+        :description: 记录请求链路日志(info)
+        :param msg: 日志内容
+        :return 无
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.logging_link(msg, "info", extra_dict)
+        except:
+            pass
+
+    def logging_link_error(self, msg, extra_dict=None):
+        """
+        :description: 记录请求链路日志(error)
+        :param msg: 日志内容
+        :return 无
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.logging_link(msg, "error", extra_dict)
+        except:
+            pass
+
+    def logging_link_sql(self, msg, extra_dict=None):
+        """
+        :description: 记录请求链路日志(sql)
+        :param msg: 日志内容
+        :return 无
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.logging_link(msg, "sql", extra_dict)
+        except:
+            pass
+
 
 def filter_check_params(must_params=None):
     """
